@@ -277,10 +277,13 @@ def nlu_list_examples(
 ):
 
     setup_logger(log_level=log_level)
+    prepared_flag = False
+    if prepared == "true":
+        prepared_flag = True
     loop = asyncio.new_event_loop()
     loop.run_until_complete(
         list_examples(
-            project_id, language, prepared, type, intent, page_number, page_size
+            project_id, language, prepared_flag, type, intent, page_number, page_size
         )
     )
     loop.run_until_complete(get_async_http_session().close())
